@@ -118,6 +118,10 @@ class ModelResource(object):
         # Filter the queryset by the passed clause.
         return queryset.filter(clause).distinct()
 
+    def count(self, queryset):
+        # Return the count of the queryset.
+        return queryset.count()
+
     def read(self):
         # Initialize the query to the model.
         queryset = self.session.query(self.meta.model)
@@ -148,7 +152,7 @@ class ModelResource(object):
             self.request.user, 'read', self, queryset)
 
         # Return the queryset.
-        return queryset.all() if self.slug is None else queryset.first()
+        return queryset if self.slug is None else queryset.first()
 
     def create(self, data):
         # Instantiate a new target.
@@ -186,7 +190,7 @@ class ModelResource(object):
 
         # Flush the target and expire attributes.
         self.session.flush()
-        
+
         # Refresh the target object to avoid inconsistencies with storage.
         self.session.expire(target)
 
